@@ -42,7 +42,7 @@ druid_finished_cb (GnomeDbDsnConfigDruid *druid, gboolean error, gpointer user_d
 		if (dsn_info)
 			gda_config_save_data_source_info (dsn_info);
 		else
-			gnome_db_show_error (_("No valid data source info was created"));
+			gnome_db_show_error (NULL, _("No valid data source info was created"));
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (user_data));
