@@ -322,11 +322,26 @@ gnome_db_entry_wrapper_get_property (GObject *object,
 	}
 }
 
+/**
+ * gnome_db_entry_wrapper_contents_changed
+ * @mgwrap: a #GnomeDbEntryWrapper widget
+ *
+ * Signals to @gwrap that the entry has changed
+ */
+void
+gnome_db_entry_wrapper_contents_changed (GnomeDbEntryWrapper *mgwrap)
+{
+	g_return_if_fail (GNOME_DB_IS_ENTRY_WRAPPER (mgwrap));
+	g_return_if_fail (((GnomeDbEntryWrapper *) mgwrap)->priv);
+
+	contents_changed_cb (NULL, mgwrap);
+}
 
 static void gnome_db_entry_wrapper_emit_signal (GnomeDbEntryWrapper *mgwrap);
 static void
 contents_changed_cb (GtkWidget *entry, GnomeDbEntryWrapper *mgwrap)
 {
+	/* @entry is not used */
 	if (! mgwrap->priv->signals_blocked) {
 		mgwrap->priv->null_forced = FALSE;
 		mgwrap->priv->default_forced = FALSE;
@@ -451,7 +466,7 @@ gnome_db_entry_wrapper_get_value (GnomeDbDataEntry *iface)
 		}
 		else {
 			check_correct_init (mgwrap);
-			value = (*mgwrap->priv->real_class->real_get_value) (mgwrap);
+			value = (mgwrap->priv->real_class->real_get_value) (mgwrap);
 		}
 	}
 
@@ -471,11 +486,15 @@ gnome_db_entry_wrapper_set_value_orig (GnomeDbDataEntry *iface, const GValue *va
 	check_correct_init (mgwrap);
 
 	/* compare existing value and the one provided as argument */
-	evalue = gnome_db_entry_wrapper_get_value (iface);
-	if (! gda_value_compare_ext ((GValue *) value, evalue))
-		changed = FALSE;
-	if (evalue)
-		gda_value_free (evalue);
+	if (mgwrap->priv->real_class->value_is_equal_to)
+		changed = ! mgwrap->priv->real_class->value_is_equal_to (mgwrap, value);
+	else {
+		evalue = gnome_db_entry_wrapper_get_value (iface);
+		if (! gda_value_compare_ext ((GValue *) value, evalue))
+			changed = FALSE;
+		if (evalue)
+			gda_value_free (evalue);
+	}
 
 	/* get rid on any existing orig value */
 	if (mgwrap->priv->value_orig) { 
@@ -663,23 +682,39 @@ gnome_db_entry_wrapper_get_attributes (GnomeDbDataEntry *iface)
 {
 	guint retval = 0;
 	GnomeDbEntryWrapper *mgwrap;
-	GValue *value;
+	GValue *value = NULL;
+	gboolean has_current_value;
+	gboolean value_is_null = FALSE;
 
 	g_return_val_if_fail (GNOME_DB_IS_ENTRY_WRAPPER (iface), 0);
 	mgwrap = GNOME_DB_ENTRY_WRAPPER (iface);
 	g_return_val_if_fail (mgwrap->priv, 0);
 
-	value = gnome_db_entry_wrapper_get_value (iface);
-
-	/* NULL? */
-	if (G_VALUE_TYPE (value) == GDA_TYPE_NULL) {
-		if (mgwrap->priv->default_forced) {
-			if (mgwrap->priv->null_forced)
-				retval = retval | GDA_VALUE_ATTR_IS_NULL;
-		}
-		else
-			retval = retval | GDA_VALUE_ATTR_IS_NULL;
+	if (!mgwrap->priv->real_class->value_is_equal_to || 
+	    !mgwrap->priv->real_class->value_is_null) {
+		value = gnome_db_entry_wrapper_get_value (iface);
+		has_current_value = TRUE;
 	}
+	else
+		has_current_value = FALSE;
+	
+	/* NULL? */
+	if (has_current_value) {
+		if (G_VALUE_TYPE (value) == GDA_TYPE_NULL) {
+			if (mgwrap->priv->default_forced) {
+				if (mgwrap->priv->null_forced)
+					value_is_null = TRUE;
+			}
+			else
+				value_is_null = TRUE;
+		}
+	}
+	else {
+		if ((mgwrap->priv->real_class->value_is_null) (mgwrap))
+			value_is_null = TRUE;
+	}
+	if (value_is_null)
+		retval = retval | GDA_VALUE_ATTR_IS_NULL;
 
 	/* can be NULL? */
 	if (mgwrap->priv->null_possible) 
@@ -694,15 +729,21 @@ gnome_db_entry_wrapper_get_attributes (GnomeDbDataEntry *iface)
 		retval = retval | GDA_VALUE_ATTR_CAN_BE_DEFAULT;
 	
 	/* is unchanged */
-	if (mgwrap->priv->value_orig && 
-	    (G_VALUE_TYPE (value) == G_VALUE_TYPE (mgwrap->priv->value_orig))) {
-		if (gda_value_is_null (value)) 
-			retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
-		else {
-			if (! gda_value_compare (value, mgwrap->priv->value_orig))
+	if (has_current_value) {
+		if (mgwrap->priv->value_orig && 
+		    (G_VALUE_TYPE (value) == G_VALUE_TYPE (mgwrap->priv->value_orig))) {
+			if (gda_value_is_null (value)) 
 				retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
+			else {
+				if (! gda_value_compare (value, mgwrap->priv->value_orig))
+					retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
+			}
 		}
 	}
+	else {
+		if ((mgwrap->priv->real_class->value_is_equal_to) (mgwrap, mgwrap->priv->value_orig))
+			retval = retval | GDA_VALUE_ATTR_IS_UNCHANGED;
+	}
 
 	/* actions shown */
 	if (mgwrap->priv->show_actions)
@@ -710,8 +751,8 @@ gnome_db_entry_wrapper_get_attributes (GnomeDbDataEntry *iface)
 
 	/* data valid? */
 	if (! (mgwrap->priv->default_forced && mgwrap->priv->default_possible)) {
-		if (/*(gda_value_is_null (value) && !mgwrap->priv->null_forced) ||*/
-		    (gda_value_is_null (value) && !mgwrap->priv->null_possible))
+		if (/*(value_is_null && !mgwrap->priv->null_forced) ||*/
+		    (value_is_null && !mgwrap->priv->null_possible))
 			retval = retval | GDA_VALUE_ATTR_DATA_NON_VALID;
 	}
 
@@ -720,7 +761,8 @@ gnome_db_entry_wrapper_get_attributes (GnomeDbDataEntry *iface)
 		retval = retval | GDA_VALUE_ATTR_HAS_VALUE_ORIG;
 	}
 	
-	gda_value_free (value);
+	if (has_current_value)
+		gda_value_free (value);
 
 	return retval;
 }
@@ -753,7 +795,7 @@ gnome_db_entry_wrapper_expand_in_layout (GnomeDbDataEntry *iface)
 	g_return_val_if_fail (mgwrap->priv, FALSE);
 	check_correct_init (mgwrap);
 
-	return (*mgwrap->priv->real_class->expand_in_layout) (mgwrap);
+	return (mgwrap->priv->real_class->expand_in_layout) (mgwrap);
 }
 
 static void
