@@ -64,7 +64,9 @@ enum
         PROP_0,
 	PROP_LAYOUT_SPEC,
 	PROP_PARAMLIST,
-	PROP_HEADERS_SENSITIVE
+	PROP_HEADERS_SENSITIVE,
+	PROP_SHOW_ACTIONS,
+	PROP_ENTRIES_AUTO_DEFAULT
 };
 
 struct _GnomeDbBasicFormPriv
@@ -82,6 +84,8 @@ struct _GnomeDbBasicFormPriv
 
 	gboolean                headers_sensitive;
 	gboolean                forward_param_updates; /* forward them to the GnomeDbDataEntry widgets ? */
+	gboolean                show_actions;
+	gboolean                entries_auto_default;
 	GtkTooltips            *tooltips;
 };
 
@@ -138,6 +142,7 @@ gnome_db_basic_form_class_init (GnomeDbBasicFormClass * class)
 	/* Properties */
         object_class->set_property = gnome_db_basic_form_set_property;
         object_class->get_property = gnome_db_basic_form_get_property;
+	
 	g_object_class_install_property (object_class, PROP_LAYOUT_SPEC,
 					 g_param_spec_pointer ("layout_spec", 
 							       _("Pointer to a GnomeDbFormLayoutSpec structure"), NULL,
@@ -148,7 +153,17 @@ gnome_db_basic_form_class_init (GnomeDbBasicFormClass * class)
                                                                G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_HEADERS_SENSITIVE,
 					 g_param_spec_boolean ("headers_sensitive",
-							       _("Defines if entry headers are sensitive with entries"), 
+							       _("Entry's headers are sensitive"), 
+							       NULL, FALSE,
+							       G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class, PROP_SHOW_ACTIONS,
+					 g_param_spec_boolean ("show_actions",
+							       _("Show entries actions"), 
+							       NULL, FALSE,
+							       G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class, PROP_ENTRIES_AUTO_DEFAULT,
+					 g_param_spec_boolean ("entries_auto_default",
+							       _("Entries Auto-default"), 
 							       NULL, FALSE,
 							       G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -167,9 +182,13 @@ gnome_db_basic_form_init (GnomeDbBasicForm * wid)
 	wid->priv->signal_ids = NULL;
 
 	wid->priv->headers_sensitive = FALSE;
+	wid->priv->show_actions = FALSE;
+	wid->priv->entries_auto_default = FALSE;
 
 	wid->priv->forward_param_updates = TRUE;
 	wid->priv->tooltips = gtk_tooltips_new ();
+	g_object_ref (G_OBJECT (wid->priv->tooltips));
+	gtk_object_sink (GTK_OBJECT (wid->priv->tooltips));
 }
 
 static void widget_shown_cb (GtkWidget *wid, GnomeDbBasicForm *form);
@@ -269,7 +288,7 @@ paramlist_destroyed_cb (GdaParameterList *paramlist, GnomeDbBasicForm *form)
 	/* render all the entries non sensitive */
 	list = form->priv->entries;
 	while (list) {
-		gtk_widget_set_sensitive (GTK_WIDGET (list->data), FALSE);
+		gnome_db_data_entry_set_editable (GNOME_DB_DATA_ENTRY (list->data), FALSE);
 		list = g_slist_next (list);
 	}
 }
@@ -298,6 +317,8 @@ gnome_db_basic_form_dispose (GObject *object)
 
 		gnome_db_basic_form_clean (form);
 
+		g_object_unref (G_OBJECT (form->priv->tooltips));
+
 		/* the private area itself */
 		g_free (form->priv);
 		form->priv = NULL;
@@ -387,6 +408,12 @@ gnome_db_basic_form_set_property (GObject *object,
 		case PROP_HEADERS_SENSITIVE:
 			form->priv->headers_sensitive = g_value_get_boolean (value);
 			break;
+		case PROP_SHOW_ACTIONS:
+			gnome_db_basic_form_show_entries_actions(form, g_value_get_boolean(value));
+			break;
+		case PROP_ENTRIES_AUTO_DEFAULT:
+			gnome_db_basic_form_set_entries_auto_default(form, g_value_get_boolean(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -411,6 +438,12 @@ gnome_db_basic_form_get_property (GObject *object,
 		case PROP_HEADERS_SENSITIVE:
 			g_value_set_boolean (value, form->priv->headers_sensitive);
 			break;
+		case PROP_SHOW_ACTIONS:
+			g_value_set_boolean(value, form->priv->show_actions);
+			break;
+		case PROP_ENTRIES_AUTO_DEFAULT:
+			g_value_set_boolean(value, form->priv->entries_auto_default);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -437,6 +470,10 @@ gnome_db_basic_form_clean (GnomeDbBasicForm *form)
 	}
 
 	/* destroy all the widgets */
+	while (form->priv->entries)
+		/* destroy any remaining widget */
+		gtk_widget_destroy (GTK_WIDGET (form->priv->entries->data));
+
 	if (form->priv->entries_table) {
 		gtk_widget_destroy (form->priv->entries_table);
 		form->priv->entries_table = NULL;
@@ -449,9 +486,7 @@ gnome_db_basic_form_clean (GnomeDbBasicForm *form)
 		layout_spec_free (form->priv->layout_spec);
 		form->priv->layout_spec = NULL;
 	}
-	g_slist_free (form->priv->entries);
-	form->priv->entries = NULL;
-
+	
 	g_slist_free (form->priv->not_null_labels);
 	form->priv->not_null_labels = NULL;
 
@@ -471,6 +506,7 @@ layout_spec_free (GnomeDbFormLayoutSpec *spec)
 }
 
 static void entry_destroyed_cb (GtkWidget *entry, GnomeDbBasicForm *form);
+static void label_destroyed_cb (GtkWidget *label, GnomeDbBasicForm *form);
 
 /*
  * create the entries in the widget
@@ -480,17 +516,21 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 {
 	GSList *list;
 	gint i;
+	gboolean form_expand = FALSE;
+	GdaDict *dict;
 	
 	/* parameters list management */
 	if (!form->priv->paramlist || !form->priv->paramlist->groups_list)
 		/* nothing to do */
 		return;
 
+	dict = gda_object_get_dict (GDA_OBJECT (form->priv->paramlist));
+
 	/* allocating space for the signal ids and connect to the parameter's changes */
 	form->priv->signal_ids = g_new0 (gulong, g_slist_length (form->priv->paramlist->parameters));
 	i = 0;
 
-	/* creating all the entries, and putting them into the form->priv->entries list */
+	/* creating all the data entries, and putting them into the form->priv->entries list */
 	list = form->priv->paramlist->groups_list;
 	while (list) {
 		GdaParameterListGroup *group;
@@ -500,8 +540,8 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 		if (! group->nodes_source) { 
 			/* there is only one non-constrained parameter */
 			GdaParameter *param;
-			GdaValueType type;
-			const GdaValue *val, *default_val, *value;
+			GType type;
+			const GValue *val, *default_val, *value;
 			gboolean nnul;
 			gchar *plugin = NULL;
 
@@ -514,15 +554,15 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 			nnul = gda_parameter_get_not_null (param);
 
 			/* determine initial value */
-			type = gda_parameter_get_gda_type (param);
+			type = gda_parameter_get_g_type (param);
 			value = val;
 			if (!value && default_val && 
-			    (gda_value_get_type ((GdaValue *) default_val) == type))
+			    (G_VALUE_TYPE ((GValue *) default_val) == type))
 				value = default_val;
 			
 			/* create entry */
-			g_object_get (G_OBJECT (param), "handler_plugin", &plugin, NULL);
-			entry = GTK_WIDGET (gnome_db_util_new_data_entry (type, plugin));
+			g_object_get (G_OBJECT (param), "entry_plugin", &plugin, NULL);
+			entry = GTK_WIDGET (gnome_db_util_new_data_entry (dict, type, plugin));
 
 
 			/* set current value */
@@ -530,7 +570,7 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 
 			if (!nnul ||
 			    (nnul && value && 
-			     (gda_value_get_type ((GdaValue *) value) != GDA_VALUE_TYPE_NULL)))
+			     (G_VALUE_TYPE ((GValue *) value) != GDA_TYPE_NULL)))
 				gnome_db_data_entry_set_value_orig (GNOME_DB_DATA_ENTRY (entry), value);
 			
 			if (default_val) {
@@ -624,9 +664,11 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 				g_print ("Box named %s => %p\n", box_name, box);
 				g_free (box_name);
 				if (box) {
-					gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (list->data),
-							    gnome_db_data_entry_expand_in_layout (GNOME_DB_DATA_ENTRY (list->data)),
-							    TRUE, 0);
+					gboolean expand;
+					expand = gnome_db_data_entry_expand_in_layout (GNOME_DB_DATA_ENTRY (list->data));
+					form_expand = form_expand || expand;
+
+					gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (list->data), expand, TRUE, 0);
 					gtk_widget_show (GTK_WIDGET (list->data));
 					if (! g_object_get_data (G_OBJECT (box), "show_actions")) 
 						gnome_db_data_entry_set_attributes (GNOME_DB_DATA_ENTRY (list->data),
@@ -652,7 +694,7 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 		gtk_table_set_row_spacings (GTK_TABLE (table), 5);
 		gtk_table_set_col_spacings (GTK_TABLE (table), 5);
 		form->priv->entries_table = table;
-		gtk_box_pack_start (GTK_BOX (form), table,  FALSE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (form), table, TRUE, TRUE, 0);
 		list = form->priv->entries;
 		i = 0;
 		while (list) {
@@ -673,18 +715,15 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 				str2 = g_strdup_printf ("%s:", str);
 				evbox = gtk_event_box_new ();
 				label = gtk_label_new (str2);
-				if (gda_parameter_get_not_null (param)) {
-					gpointer data = NULL;
+				if (gda_parameter_get_not_null (param)) 
 					form->priv->not_null_labels = g_slist_prepend (form->priv->not_null_labels, label);
-					data = form->priv->not_null_labels->data;
-				}
 				
 				gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 				g_free (str2);
 				gtk_container_add (GTK_CONTAINER (evbox), label);
 				
 				gtk_table_attach (GTK_TABLE (table), evbox, 0, 1, i, i+1,
-						  GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
+						  GTK_FILL | GTK_SHRINK, GTK_SHRINK, 0, 0);
 				gtk_widget_show (evbox);
 				gtk_widget_show (label);
 				entry_label = evbox;
@@ -726,7 +765,7 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 				gtk_container_add (GTK_CONTAINER (evbox), label);
 				
 				gtk_table_attach (GTK_TABLE (table), evbox, 0, 1, i, i+1,
-						  GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 0, 0);
+						  GTK_FILL | GTK_SHRINK, GTK_SHRINK, 0, 0);
 				gtk_widget_show (evbox);
 				gtk_widget_show (label);
 				entry_label = evbox;
@@ -738,11 +777,15 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 
 			/* add the entry itself to the table */
 			expand = gnome_db_data_entry_expand_in_layout (GNOME_DB_DATA_ENTRY (list->data));
+			form_expand = form_expand || expand;
 			gtk_table_attach (GTK_TABLE (table), GTK_WIDGET (list->data), 1, 2, i, i+1,
-					  GTK_FILL | GTK_SHRINK | GTK_EXPAND, 
-					  GTK_FILL | GTK_SHRINK | expand? GTK_EXPAND : 0, 0, 0);
+					  GTK_FILL | GTK_EXPAND, 
+					  form_expand ? (GTK_FILL | GTK_EXPAND) : GTK_SHRINK, 0, 0);
 			gtk_widget_show (GTK_WIDGET (list->data));
 			g_object_set_data (G_OBJECT (list->data), "entry_label", entry_label);
+			if (entry_label) 
+				g_signal_connect (entry_label, "destroy",
+						  G_CALLBACK (label_destroyed_cb), form);
 			g_object_set_data (G_OBJECT (list->data), "row_no", GINT_TO_POINTER (i));
 			
 			list = g_slist_next (list);
@@ -751,12 +794,43 @@ gnome_db_basic_form_fill (GnomeDbBasicForm *form)
 		mark_not_null_entry_labels (form, TRUE);
 		gtk_widget_show (table);
 	}
+
+	g_object_set_data (G_OBJECT (form), "expand", GINT_TO_POINTER (form_expand));
+	
+	/* Set the Show actions in the entries */
+	gnome_db_basic_form_show_entries_actions(form, form->priv->show_actions);
+	/* Set the Auto entries default in the entries */
+	gnome_db_basic_form_set_entries_auto_default(form, form->priv->entries_auto_default);
 }
 
 static void
 entry_destroyed_cb (GtkWidget *entry, GnomeDbBasicForm *form)
 {
-	/* debug only function */
+	GtkWidget *label_entry;
+
+	form->priv->entries = g_slist_remove (form->priv->entries, entry);
+	label_entry = g_object_get_data (G_OBJECT (entry), "entry_label");
+	if (label_entry) {
+		/* don't take care of label_entry anymore */
+		g_signal_handlers_disconnect_by_func (G_OBJECT (label_entry),
+						      G_CALLBACK (label_destroyed_cb), form);
+		g_object_set_data (G_OBJECT (entry), "entry_label", NULL);
+	}
+}
+
+static void
+label_destroyed_cb (GtkWidget *label, GnomeDbBasicForm *form)
+{
+	GSList *list = form->priv->entries;
+
+	while (list) {
+		if (g_object_get_data (G_OBJECT (list->data), "entry_label") == label) {
+			g_object_set_data (G_OBJECT (list->data), "entry_label", NULL);
+			list = NULL;
+		}
+		else
+			list = list->next;
+	}
 }
 
 /*
@@ -796,7 +870,7 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 	attr = gnome_db_data_entry_get_attributes (entry);
 	param = g_object_get_data (G_OBJECT (entry), "param");
 	if (param) { /* single parameter */
-		GdaValue *value;
+		GValue *value;
 		
 		form->priv->forward_param_updates = FALSE;
 
@@ -844,7 +918,7 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 
 			/* parameter's value */
 			param = GDA_PARAMETER_LIST_NODE (params->data)->param;
-			gda_parameter_set_value (param, (GdaValue *)(list->data));
+			gda_parameter_set_value (param, (GValue *)(list->data));
 #ifdef debug_signal
 			g_print (">> 'PARAM_CHANGED' from %s\n", __FUNCTION__);
 #endif
@@ -860,6 +934,7 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 		}
 		g_slist_free (values);
 
+#ifdef PROXY_STORE_EXTRA_VALUES
 		/* updating the GdaDataProxy if there is one */
 		if (GDA_IS_DATA_MODEL_ITER (form->priv->paramlist)) {
 			GdaDataProxy *proxy;
@@ -874,10 +949,10 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 
 				all_new_values = gnome_db_entry_combo_get_all_values (GNOME_DB_ENTRY_COMBO (entry));
 				for (i = 0; i < group->nodes_source->shown_n_cols; i++) {
-					GdaValue *value;
+					GValue *value;
 					
 					col = group->nodes_source->shown_cols_index[i];
-					value = (GdaValue *) g_slist_nth_data (all_new_values, col);
+					value = (GValue *) g_slist_nth_data (all_new_values, col);
 					gda_data_proxy_set_model_row_value (proxy, 
 									    group->nodes_source->data_model,
 									    proxy_row, col, value);
@@ -885,6 +960,7 @@ entry_contents_modified (GnomeDbDataEntry *entry, GnomeDbBasicForm *form)
 				g_slist_free (all_new_values);
 			}
 		}
+#endif
 	}
 }
 
@@ -899,7 +975,7 @@ parameter_changed_cb (GdaParameter *param, GnomeDbDataEntry *entry)
 {
 	GnomeDbBasicForm *form = g_object_get_data (G_OBJECT (entry), "form");
 	GdaParameterListGroup *group = g_object_get_data (G_OBJECT (entry), "group");
-	const GdaValue *value = gda_parameter_get_value (param);
+	const GValue *value = gda_parameter_get_value (param);
 
 	if (form->priv->forward_param_updates) {
 		gboolean param_valid;
@@ -922,11 +998,11 @@ parameter_changed_cb (GdaParameter *param, GnomeDbDataEntry *entry)
 			gboolean allnull = TRUE;
 
 			while (list) {
-				const GdaValue *pvalue;
+				const GValue *pvalue;
 				pvalue = gda_parameter_get_value (GDA_PARAMETER_LIST_NODE (list->data)->param);
-				values = g_slist_append (values, (GdaValue *) pvalue);
+				values = g_slist_append (values, (GValue *) pvalue);
 				if (allnull && pvalue && 
-				    (gda_value_get_type ((GdaValue *) pvalue) != GDA_VALUE_TYPE_NULL))
+				    (G_VALUE_TYPE ((GValue *) pvalue) != GDA_TYPE_NULL))
 					allnull = FALSE;
 
 				list = g_slist_next (list);
@@ -1005,11 +1081,11 @@ gnome_db_basic_form_set_current_as_orig (GnomeDbBasicForm *form)
 			gboolean allnull = TRUE;
 			
 			while (params) {
-				const GdaValue *pvalue;
+				const GValue *pvalue;
 				pvalue = gda_parameter_get_value (GDA_PARAMETER_LIST_NODE (params->data)->param);
-				values = g_slist_append (values, (GdaValue *) pvalue);
+				values = g_slist_append (values, (GValue *) pvalue);
 				if (allnull && pvalue && 
-				    (gda_value_get_type ((GdaValue *) pvalue) != GDA_VALUE_TYPE_NULL))
+				    (G_VALUE_TYPE ((GValue *) pvalue) != GDA_TYPE_NULL))
 					allnull = FALSE;
 				
 				params = g_slist_next (params);
@@ -1111,6 +1187,7 @@ gnome_db_basic_form_show_entries_actions (GnomeDbBasicForm *form, gboolean show_
 	g_return_if_fail (form->priv);
 
 	show = show_actions ? GDA_VALUE_ATTR_ACTIONS_SHOWN : 0;
+	form->priv->show_actions = show_actions;
 
 	entries = form->priv->entries;
 	while (entries) {
@@ -1151,7 +1228,7 @@ gnome_db_basic_form_reset (GnomeDbBasicForm *form)
 		}
 		else {
 			/* non combo entry */
-			const GdaValue *value;
+			const GValue *value;
 
 			value = gnome_db_data_entry_get_value_orig (GNOME_DB_DATA_ENTRY (list->data));
 			gnome_db_data_entry_set_value (GNOME_DB_DATA_ENTRY (list->data), value);
@@ -1173,136 +1250,87 @@ gnome_db_basic_form_reset (GnomeDbBasicForm *form)
 void
 gnome_db_basic_form_entry_show (GnomeDbBasicForm *form, GdaParameter *param, gboolean show)
 {
-	GSList *entries;
+	GtkWidget *entry;
 
 	g_return_if_fail (form && IS_GNOME_DB_BASIC_FORM (form));
 	g_return_if_fail (form->priv);
 
-	entries = form->priv->entries;
-	while (entries) {
-		GtkWidget *entry = NULL;
-		GdaParameter *thisparam = g_object_get_data (G_OBJECT (entries->data), "param");
+	entry = gnome_db_basic_form_get_entry_widget (form, param);
 
-		if (thisparam) {
-			if (thisparam == param)
-				entry = GTK_WIDGET (entries->data);
-		}
-		else {
-			/* multiple parameters */
-			GSList *params;
-			GdaParameterListGroup *group;
-
-			group = g_object_get_data (G_OBJECT (entries->data), "group");
-			params = group->nodes;
-			while (params && !entry) {
-				if (GDA_PARAMETER_LIST_NODE (params->data)->param == (gpointer) param)
-					entry = GTK_WIDGET (entries->data);
-				params = g_slist_next (params);
+	if (entry) {
+		gint row = -1;
+		GtkWidget *entry_label = g_object_get_data (G_OBJECT (entry), "entry_label");
+		
+		if (form->priv->entries_table)
+			row = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "row_no"));
+		
+		if (show) {
+			if (g_slist_find (form->priv->hidden_entries, entry)) {
+				form->priv->hidden_entries = g_slist_remove (form->priv->hidden_entries, entry);
+				g_signal_handlers_disconnect_by_func (G_OBJECT (entry), 
+								      G_CALLBACK (widget_shown_cb), form);
 			}
-		}
-
-		if (entry) {
-			gint row = -1;
-			GtkWidget *entry_label = g_object_get_data (G_OBJECT (entry), "entry_label");
-
-			if (form->priv->entries_table)
-				row = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (entry), "row_no"));
-
-			if (show) {
-				if (g_slist_find (form->priv->hidden_entries, entry)) {
-					form->priv->hidden_entries = g_slist_remove (form->priv->hidden_entries, entry);
-					g_signal_handlers_disconnect_by_func (G_OBJECT (entry), 
+			gtk_widget_show (entry);
+			
+			if (entry_label) {
+				if (g_slist_find (form->priv->hidden_entries, entry_label)) {
+					form->priv->hidden_entries = g_slist_remove (form->priv->hidden_entries, 
+										     entry_label);
+					g_signal_handlers_disconnect_by_func (G_OBJECT (entry_label), 
 									      G_CALLBACK (widget_shown_cb), form);
 				}
-				gtk_widget_show (entry);
-
-				if (entry_label) {
-					if (g_slist_find (form->priv->hidden_entries, entry_label)) {
-						form->priv->hidden_entries = g_slist_remove (form->priv->hidden_entries, 
-											     entry_label);
-						g_signal_handlers_disconnect_by_func (G_OBJECT (entry_label), 
-										      G_CALLBACK (widget_shown_cb), form);
-					}
-					gtk_widget_show (entry_label);
-				}
-				if (row > -1) 
-					gtk_table_set_row_spacing (GTK_TABLE (form->priv->entries_table), row, 5);
+				gtk_widget_show (entry_label);
 			}
-			else {
-				if (!g_slist_find (form->priv->hidden_entries, entry)) {
-					form->priv->hidden_entries = g_slist_append (form->priv->hidden_entries, entry);
-					g_signal_connect_after (G_OBJECT (entry), "show", 
+			if (row > -1) 
+				gtk_table_set_row_spacing (GTK_TABLE (form->priv->entries_table), row, 5);
+		}
+		else {
+			if (!g_slist_find (form->priv->hidden_entries, entry)) {
+				form->priv->hidden_entries = g_slist_append (form->priv->hidden_entries, entry);
+				g_signal_connect_after (G_OBJECT (entry), "show", 
+							G_CALLBACK (widget_shown_cb), form);
+			}
+			gtk_widget_hide (entry);
+			
+			if (entry_label) {
+				if (!g_slist_find (form->priv->hidden_entries, entry_label)) {
+					form->priv->hidden_entries = g_slist_append (form->priv->hidden_entries, 
+										     entry_label);
+					g_signal_connect_after (G_OBJECT (entry_label), "show", 
 								G_CALLBACK (widget_shown_cb), form);
 				}
-				gtk_widget_hide (entry);
-
-				if (entry_label) {
-					if (!g_slist_find (form->priv->hidden_entries, entry_label)) {
-						form->priv->hidden_entries = g_slist_append (form->priv->hidden_entries, 
-											     entry_label);
-						g_signal_connect_after (G_OBJECT (entry_label), "show", 
-									G_CALLBACK (widget_shown_cb), form);
-					}
-					gtk_widget_hide (entry_label);
-				}
-				if (row > -1)
-					gtk_table_set_row_spacing (GTK_TABLE (form->priv->entries_table), row, 0);
+				gtk_widget_hide (entry_label);
 			}
+			if (row > -1)
+				gtk_table_set_row_spacing (GTK_TABLE (form->priv->entries_table), row, 0);
 		}
-
-		entries = g_slist_next (entries);
 	}
 }
 
 /**
- * gnome_db_basic_form_entry_set_sensitive
+ * gnome_db_basic_form_entry_set_editable
  * @form: a #GnomeDbBasicForm widget
  * @param: a #GdaParameter object
- * @sensitive:
+ * @editable:
  *
- * Shows or hides the #GnomeDbDataEntry in @form which corresponds to the
- * @param parameter
+ * Sets the #GnomeDbDataEntry in @form which corresponds to the
+ * @param parameter editable or not
  */
 void
-gnome_db_basic_form_entry_set_sensitive (GnomeDbBasicForm *form, GdaParameter *param, gboolean sensitive)
+gnome_db_basic_form_entry_set_editable (GnomeDbBasicForm *form, GdaParameter *param, gboolean editable)
 {
-	GSList *entries;
+	GtkWidget *entry;
 
 	g_return_if_fail (form && IS_GNOME_DB_BASIC_FORM (form));
 	g_return_if_fail (form->priv);
 
-	entries = form->priv->entries;
-	while (entries) {
-		GtkWidget *entry = NULL;
-		GdaParameter *thisparam = g_object_get_data (G_OBJECT (entries->data), "param");
-
-		if (thisparam) {
-			if (thisparam == param)
-				entry = GTK_WIDGET (entries->data);
-		}
-		else {
-			/* multiple parameters */
-			GSList *params;
-			GdaParameterListGroup *group;
-
-			group = g_object_get_data (G_OBJECT (entries->data), "group");
-			params = group->nodes;
-			while (params && !entry) {
-				if (GDA_PARAMETER_LIST_NODE (params->data)->param == (gpointer) param)
-					entry = GTK_WIDGET (entries->data);
-				params = g_slist_next (params);
-			}
-		}
-
-		if (entry) {
-			GtkWidget *entry_label = g_object_get_data (G_OBJECT (entry), "entry_label");
-
-			gtk_widget_set_sensitive (entry, sensitive);
-			if (entry_label)
-				gtk_widget_set_sensitive (entry_label, sensitive || !form->priv->headers_sensitive);
-		}
-
-		entries = g_slist_next (entries);
+	entry = gnome_db_basic_form_get_entry_widget (form, param);
+	if (entry) {
+		/* GtkWidget *entry_label = g_object_get_data (G_OBJECT (entry), "entry_label"); */
+		
+		gnome_db_data_entry_set_editable (GNOME_DB_DATA_ENTRY (entry), editable);
+		/*if (entry_label)
+		  gtk_widget_set_sensitive (entry_label, editable || !form->priv->headers_sensitive);*/
 	}
 }
 
@@ -1326,7 +1354,8 @@ gnome_db_basic_form_set_entries_auto_default (GnomeDbBasicForm *form, gboolean a
 
 	g_return_if_fail (form && IS_GNOME_DB_BASIC_FORM (form));
 	g_return_if_fail (form->priv);
-
+	
+	form->priv->entries_auto_default = auto_default;
 	entries = form->priv->entries;
 	while (entries) {
 		if (g_object_class_find_property (G_OBJECT_GET_CLASS (entries->data), "set_default_if_invalid"))
@@ -1362,6 +1391,77 @@ gnome_db_basic_form_set_entries_default (GnomeDbBasicForm *form)
 
 static void form_param_changed (GnomeDbBasicForm *form, GdaParameter *param, gboolean is_user_modif, GtkDialog *dlg);
 
+/**
+ * gnome_db_basic_form_get_entry_widget
+ * @form: a #GnomeDbBasicForm widget
+ * @param: a #GdaParameter object
+ *
+ * Get the #GnomeDbDataEntry in @form which corresponds to the param parameter.
+ *
+ * Returns: the requested widget, or %NULL if not found
+ */
+GtkWidget *
+gnome_db_basic_form_get_entry_widget (GnomeDbBasicForm *form, GdaParameter *param)
+{
+	GSList *entries;
+	GtkWidget *entry = NULL;
+
+	g_return_val_if_fail (IS_GNOME_DB_BASIC_FORM (form), NULL);
+	g_return_val_if_fail (form->priv, NULL);
+
+	entries = form->priv->entries;
+	while (entries && !entry) {
+		GdaParameter *thisparam = g_object_get_data (G_OBJECT (entries->data), "param");
+
+		if (thisparam) {
+			if (thisparam == param)
+				entry = GTK_WIDGET (entries->data);
+		}
+		else {
+			/* multiple parameters */
+			GSList *params;
+			GdaParameterListGroup *group;
+
+			group = g_object_get_data (G_OBJECT (entries->data), "group");
+			params = group->nodes;
+			while (params && !entry) {
+				if (GDA_PARAMETER_LIST_NODE (params->data)->param == (gpointer) param)
+					entry = GTK_WIDGET (entries->data);
+				params = g_slist_next (params);
+			}
+		}
+
+		entries = g_slist_next (entries);
+	}
+
+	return entry;
+}
+
+/**
+ * gnome_db_basic_form_get_label_widget
+ * @form: a #GnomeDbBasicForm widget
+ * @param: a #GdaParameter object
+ *
+ * Get the label in @form which corresponds to the param parameter.
+ *
+ * Returns: the requested widget, or %NULL if not found
+ */
+GtkWidget *
+gnome_db_basic_form_get_label_widget (GnomeDbBasicForm *form, GdaParameter *param)
+{
+	GtkWidget *entry;
+
+	g_return_val_if_fail (IS_GNOME_DB_BASIC_FORM (form), NULL);
+	g_return_val_if_fail (form->priv, NULL);
+
+	entry = gnome_db_basic_form_get_entry_widget (form, param);
+	if (entry) 
+		return g_object_get_data (G_OBJECT (entry), "entry_label");
+	else
+		return NULL;
+}
+
+
 /**
  * gnome_db_basic_form_new_in_dialog
  * @dict: a #GdaDict object
@@ -1395,10 +1495,10 @@ gnome_db_basic_form_new_in_dialog (GdaParameterList *paramlist, GtkWindow *paren
 		
 	dlg = gtk_dialog_new_with_buttons (rtitle, parent,
 					   GTK_DIALOG_MODAL,
-					   GTK_STOCK_OK,
-					   GTK_RESPONSE_ACCEPT,
 					   GTK_STOCK_CANCEL,
 					   GTK_RESPONSE_REJECT,
+					   GTK_STOCK_OK,
+					   GTK_RESPONSE_ACCEPT,
 					   NULL);
 	if (header && *header) {
 		GtkWidget *label;
