@@ -55,6 +55,7 @@ enum {
 	PROP_MODEL
 };
 
+/* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -157,6 +158,11 @@ gnome_db_combo_get_property (GObject *object,
 	}
 }
 
+static void
+model_changed_cb (GdaDataModel *model, GnomeDbCombo *combo)
+{
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
+}
 
 static void
 model_destroyed_cb (GdaDataModel *model, GnomeDbCombo *combo)
@@ -164,6 +170,8 @@ model_destroyed_cb (GdaDataModel *model, GnomeDbCombo *combo)
 	g_assert (model == combo->priv->model);
 	g_signal_handlers_disconnect_by_func (model,
 					      G_CALLBACK (model_destroyed_cb), combo);
+	g_signal_handlers_disconnect_by_func (model,
+					      G_CALLBACK (model_changed_cb), combo);
 	g_object_unref (model);
 	combo->priv->model = NULL;
 }
@@ -228,7 +236,8 @@ gnome_db_combo_new ()
  * @n_cols: number of columns in the model to be shown
  * @cols_index: index of each column to be shown
  *
- * Create a new GnomeDbCombo widget with a model.
+ * Create a new GnomeDbCombo widget with a model. See gnome_db_combo_set_model() for
+ * more information about the @n_cols and @cols_index usage.
  *
  * Returns: the newly-created widget.
  */
@@ -255,14 +264,19 @@ static void cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *
  * @n_cols: number of columns in the model to be shown
  * @cols_index: index of each column to be shown
  *
- * Associate a #GdaDataModel with the given combo widget. Doing so makes the
+ * Makes @combo display data stored in @model (makes the
  * combo widget refresh its list of values and display the values contained
- * in the model, in the given position. A NULL @model will make the combo empty
+ * in the model). A NULL @model will make the combo empty
  * and disassociate the previous model, if any.
+ *
+ * if @n_cols is 0, then all the columns of @model will be displayed in @combo.
  */
 void
 gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols, gint *cols_index)
 {
+	gint ln_cols;
+	gint *lcols_index;
+	
 	g_return_if_fail (GNOME_DB_IS_COMBO (combo));
 	g_return_if_fail (model == NULL || GDA_IS_DATA_MODEL (model));
 
@@ -288,30 +302,44 @@ gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols,
 		
 		combo->priv->store = GNOME_DB_DATA_STORE (gnome_db_data_store_new (combo->priv->model));
 		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (combo->priv->store));
+		g_signal_connect (G_OBJECT (model), "changed",
+				  G_CALLBACK (model_changed_cb), combo);
 	} 
+	
+	if (!n_cols && model) {
+		gint i;
+		ln_cols = gda_data_model_get_n_columns (model);
+		lcols_index = g_new (gint, ln_cols);
+		for (i = 0; i < ln_cols; i++)
+			lcols_index [i] = i;	
+	}
+	else {
+		ln_cols = n_cols;
+		lcols_index = cols_index;
+	}
 
 	/* set columns with cell renderers*/
-	if (n_cols && model) {
+	if (ln_cols && model) {
 		gint i, index;
 		GtkCellRenderer *renderer;
 		GdaDataHandler *dh;
 		GdaDict *dict;
 
 		/* local copy */
-		combo->priv->cols_index = g_new0 (gint, n_cols);
-		combo->priv->n_cols = n_cols;
-		memcpy (combo->priv->cols_index, cols_index, sizeof (gint) * n_cols);
+		combo->priv->cols_index = g_new0 (gint, ln_cols);
+		combo->priv->n_cols = ln_cols;
+		memcpy (combo->priv->cols_index, lcols_index, sizeof (gint) * ln_cols);
 
 		/* create cell renderers */
 		dict = gda_object_get_dict (GDA_OBJECT (model));
-		for (i=0; i<n_cols; i++) {
+		for (i=0; i<ln_cols; i++) {
 			GdaColumn *column;
-			GdaValueType type;
+			GType type;
 
 			index = combo->priv->cols_index [i];
 
 			column = gda_data_model_describe_column (model, index);
-			type = gda_column_get_gda_type (column);
+			type = gda_column_get_g_type (column);
 			dh = gda_dict_get_default_handler (dict, type);
 			
 			renderer = gtk_cell_renderer_text_new ();
@@ -323,6 +351,9 @@ gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols,
 			/* Don't unref the renderer! */
 		}
 	}
+	
+	if (!n_cols && model)
+		g_free (lcols_index);
 }
 
 static void
@@ -331,7 +362,7 @@ cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *cell,
 {
 	GdaDataHandler *dh;
 	gint colnum;
-	const GdaValue *value;
+	const GValue *value;
 	gchar *str;
 	
 	dh = g_object_get_data (G_OBJECT (cell), "data_handler");
@@ -347,7 +378,7 @@ cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *cell,
  * gnome_db_combo_get_model
  * @combo: a #GnomeDbCombo widget.
  *
- * This function returns the #GdaDataModel stored in the #GnomeDbCombo.
+ * This function returns the #GdaDataModel from which @combo displays values.
  *
  * Returns: a #GdaDataModel containing the data from the #GnomeDbCombo widget.
  */
@@ -365,9 +396,12 @@ gnome_db_combo_get_model (GnomeDbCombo *combo)
 /**
  * gnome_db_combo_set_values
  * @combo: a #GnomeDbCombo widget
- * @values: a list of #GdaValue objects
+ * @values: a list of #GValue
  *
- * Sets the currently selected row of @combo from the values stored in @values.
+ * Sets the currently selected row of @combo from the values stored in @values. 
+ *
+ * WARNING: @values must contain one value for each column set to be displayed when the
+ * data model was associated to @combo.
  *
  * Returns: TRUE if a row in the model was found to match the list of values.
  */
@@ -389,14 +423,18 @@ gnome_db_combo_set_values (GnomeDbCombo *combo, const GSList *values)
  * Get a list of the currently selected values in @combo. The list itself must be free'd using g_slist_free(), 
  * but not the values it contains.
  *
- * Returns: a new list of values
+ * WARNING: @values will contain one value for each column set to be displayed when the
+ * data model was associated to @combo.
+ *
+ * Returns: a new list of values, or %NULL if there is no displayed data in @combo.
  */
 GSList *
 gnome_db_combo_get_values (GnomeDbCombo *combo)
 {
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), NULL);
 	g_return_val_if_fail (combo->priv, NULL);
-	g_return_val_if_fail (combo->priv->store, NULL);
+	if (!combo->priv->store)
+		return NULL;
 	g_return_val_if_fail (combo->priv->n_cols, NULL);
 	g_return_val_if_fail (combo->priv->cols_index, NULL);
 	
@@ -406,11 +444,11 @@ gnome_db_combo_get_values (GnomeDbCombo *combo)
 /**
  * gnome_db_combo_set_values_ext
  * @combo: a #GnomeDbCombo widget
- * @values: a list of #GdaValue objects
+ * @values: a list of #GValue objects
  * @cols_index: array of gint, index of column to which each value in @values corresponds, or %NULL
  *
  * Sets the currently selected row of @combo from the values stored in @values, assuming that
- * the values correspond to the columns listed in @cols_index. @cols_index must contain at least as
+ * these values correspond to the columns listed in @cols_index. @cols_index must contain at least as
  * many #gint as there are elements in @values;
  *
  * if @cols_index is %NULL, then it is assumed that @values has the same number of columns 
@@ -447,9 +485,9 @@ gnome_db_combo_set_values_ext (GnomeDbCombo *combo, const GSList *values, gint *
  * Get a list of the currently selected values in @combo. The list itself must be free'd using g_slist_free(), 
  * but not the values it contains. If there is no selected value in @combo, then %NULL is returned.
  *
- * if n_cols equals 0 and @cols_index is %NULL, then a #GdaValue will be returned for each column of @combo's data model.
+ * if n_cols equals 0 and @cols_index is %NULL, then a #GValue will be returned for each column of @combo's data model.
  *
- * Returns: a new list of values, or %NULL
+ * Returns: a new list of values, or %NULL if there is no displayed data in @combo.
  */
 GSList *
 gnome_db_combo_get_values_ext (GnomeDbCombo *combo, gint n_cols, gint *cols_index)
@@ -457,11 +495,12 @@ gnome_db_combo_get_values_ext (GnomeDbCombo *combo, gint n_cols, gint *cols_inde
 	GtkTreeIter iter;
 	GSList *retval = NULL;
 	gint index, nbcols;
-	GdaValue *value;
+	GValue *value;
 
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), NULL);
 	g_return_val_if_fail (combo->priv, NULL);
-	g_return_val_if_fail (combo->priv->store, NULL);
+	if (! combo->priv->store)
+		return NULL;
 	if (!n_cols) {
 		GdaDataProxy *proxy;
 
