@@ -22,7 +22,7 @@
  */
 
 #include <string.h>
-#include <libgda/gda-error.h>
+#include <libgda/gda-connection-event.h>
 #include <libgnomedb/gnome-db-error.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtkbutton.h>
@@ -48,7 +48,6 @@ struct _GnomeDbErrorPrivate {
 	GtkWidget *detail_button;
 	GtkWidget *detail_container;
 	GtkWidget *error_source;
-	GtkWidget *error_sqlstate;
 };
 
 static void gnome_db_error_class_init (GnomeDbErrorClass *klass);
@@ -63,7 +62,7 @@ static GObjectClass *parent_class = NULL;
 static void
 display_current_error (GnomeDbError *error_widget)
 {
-	GdaError *error;
+	GdaConnectionEvent *error;
 	GList *l;
 	gchar *tmp;
 
@@ -74,19 +73,17 @@ display_current_error (GnomeDbError *error_widget)
 	if (!l)
 		return;
 
-	error = GDA_ERROR (l->data);
-	tmp = g_strdup_printf ("%ld", gda_error_get_number (error));
+	error = GDA_CONNECTION_EVENT (l->data);
+	tmp = g_strdup_printf ("%ld", gda_connection_event_get_code (error));
 	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_number), tmp);
 	g_free (tmp);
 
-	tmp = (gchar *) gda_error_get_description (error);
+	tmp = (gchar *) gda_connection_event_get_description (error);
 	gnome_db_text_set_text (GTK_TEXT_VIEW (error_widget->priv->error_description),
 				tmp, strlen (tmp));
 
 	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_source),
-			    gda_error_get_source (error));
-	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_sqlstate),
-			    gda_error_get_sqlstate (error));
+			    gda_connection_event_get_source (error));
 }
 
 /*
@@ -218,7 +215,7 @@ gnome_db_error_init (GnomeDbError *error_widget, GnomeDbErrorClass *klass)
 	gtk_container_add (GTK_CONTAINER (scroll), error_widget->priv->error_description);
 
 	/* create the detail container */
-	error_widget->priv->detail_container = gnome_db_new_table_widget (3, 3, FALSE);
+	error_widget->priv->detail_container = gnome_db_new_table_widget (2, 3, FALSE);
 	gtk_table_attach (GTK_TABLE (table), error_widget->priv->detail_container,
 			  0, 4, 3, 4, GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND, 3, 3);
@@ -238,13 +235,6 @@ gnome_db_error_init (GnomeDbError *error_widget, GnomeDbErrorClass *klass)
 	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), error_widget->priv->error_source,
 			  2, 3, 1, 2, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 6, 6);
 
-	label = gnome_db_new_label_widget (_("SQL state"));
-	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), label, 1, 2, 2, 3,
-			  GTK_FILL, GTK_FILL, 6, 6);
-	error_widget->priv->error_sqlstate = gnome_db_new_entry_widget (0, FALSE);
-	gtk_table_attach (GTK_TABLE (error_widget->priv->detail_container), error_widget->priv->error_sqlstate,
-			  2, 3, 2, 3, GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL, 6, 6);
-
 	gtk_widget_hide (error_widget->priv->detail_container);
 }
 
@@ -256,7 +246,7 @@ gnome_db_error_finalize (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_ERROR (error_widget));
 
 	/* free memory */
-	gda_error_list_free (error_widget->priv->current_list);
+	gda_connection_event_list_free (error_widget->priv->current_list);
 	g_free (error_widget->priv);
 	error_widget->priv = NULL;
 
@@ -294,9 +284,8 @@ gnome_db_error_clear (GnomeDbError *error_widget)
 	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_number), "");
 	gnome_db_text_clear (GTK_TEXT_VIEW (error_widget->priv->error_description));
 	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_source), "");
-	gtk_entry_set_text (GTK_ENTRY (error_widget->priv->error_sqlstate), "");
 
-	gda_error_list_free (error_widget->priv->current_list);
+	gda_connection_event_list_free (error_widget->priv->current_list);
 	error_widget->priv->current_list = NULL;
 	error_widget->priv->nerrors = 0;
 	error_widget->priv->current_pos = 0;
@@ -318,7 +307,7 @@ gnome_db_error_show (GnomeDbError *error_widget, GList *errors)
 	g_return_if_fail (GNOME_DB_IS_ERROR (error_widget));
 
 	gnome_db_error_clear (error_widget);
-	new_list = gda_error_list_copy (errors);
+	new_list = gda_connection_event_list_copy (errors);
 	error_widget->priv->nerrors = g_list_length (new_list);
 
 	error_widget->priv->current_list = new_list;
