@@ -440,10 +440,6 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 	GError *error = NULL;
 	GdaDataModel *model;
 
-	gchar *str;
-	gboolean cmde_ok = FALSE;
-
-
 	cnc = gda_dict_get_connection (console->priv->dict);
 	if (!cnc) {
 		g_warning ("No connection associated to dictionary, can't run query");
@@ -457,10 +453,13 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 	gtk_text_buffer_get_end_iter (console->priv->buffer, &iter);
 	
 	/* run query */
-	query = GDA_QUERY (gda_query_new_from_sql (console->priv->dict, sql, NULL));
-	dset = gda_query_get_parameters_boxed (query);
-	if (fill_context_in_dialog (console, dset) != GTK_RESPONSE_ACCEPT) 
-		str = g_strdup (_("Cancelled"));
+	query = gda_query_new_from_sql (console->priv->dict, sql, NULL);
+	dset = gda_query_get_parameter_list (query);
+	if (fill_context_in_dialog (console, dset) != GTK_RESPONSE_ACCEPT) {
+		gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n", 1, "result-error", NULL);
+		gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, _("Cancelled"), -1, "result-error", NULL);
+		gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n\n", 2, "result-error", NULL);
+	}
 	else {
 		gchar *rsql;
 
@@ -472,6 +471,7 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 			string = g_string_new ("\n");
 			list = dset->parameters;
 			while (list) {
+				gchar *str;
 				const GValue *value;
 				value = gda_parameter_get_value (GDA_PARAMETER (list->data));
 				str = gda_value_stringify ((GValue *) value);
@@ -489,25 +489,64 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 		rsql = gda_renderer_render_as_sql (GDA_RENDERER (query), dset, 0, &error);
 		if (rsql) {
 			GdaCommand *cmde;
+			GList *reslist;
 
 			cmde = gda_command_new (rsql, GDA_COMMAND_TYPE_SQL, GDA_COMMAND_OPTION_STOP_ON_ERRORS);
-			model = gda_connection_execute_command (cnc, cmde, NULL, &error);
+			reslist = gda_connection_execute_command (cnc, cmde, NULL, &error);
 			gda_command_free (cmde);
-			if (model && (model != GDA_CONNECTION_EXEC_FAILED) && (gda_data_model_get_n_rows (model) > 0)) {
-				gchar *str1, *str2;
+			if (reslist) {
+				GList *list;
+				for (list = reslist; list; list = list->next) {
+					GString *string;
+				
+					string = g_string_new ("");
 
-				cmde_ok = TRUE;
-				str = gda_data_model_dump_as_string (model);
-				g_object_unref (model);
+					model = (GdaDataModel *) (list->data);
+					if (GDA_IS_DATA_MODEL (model)) {
+						gchar *str1;
+						
+						str1 = gda_data_model_dump_as_string (model);
+						g_string_append (string, str1);
+						g_free (str1);
+					}
+					else if (GDA_IS_PARAMETER_LIST (model)) {
+						GdaParameter *param;
 
-				str1 = compute_events_as_string (cnc);
-				str2 = g_strconcat (str, str1, NULL);
-				g_free (str1);
-				g_free (str);
-				str = str2;
+						param = gda_parameter_list_find_param (GDA_PARAMETER_LIST (model), 
+										       "IMPACTED_ROWS");
+						if (param) {
+							const GValue *value;
+							gint rows;
+
+							value = gda_parameter_get_value (param);
+							rows = g_value_get_int (value);
+							if (rows > 1)
+								g_string_append_printf (string, 
+											_("%d rows impacted\n"),rows);
+							else
+								g_string_append_printf (string, 
+											_("%d row impacted\n"), rows);
+						} 
+					}
+					
+					if (list->data)
+						g_object_unref (list->data);
+
+					if (list == reslist)
+						gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, 
+											  &iter, 
+											  "\n", 1, "result-ok", NULL);
+					gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter,
+										  string->str, -1,"result-ok", NULL);
+					gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, 
+										  "\n\n", 2, "result-ok", NULL);
+					g_string_free (string, TRUE);
+				}
+				g_list_free (reslist);
 			}
 			else {
-				str = NULL;
+				gchar *str = NULL;
+				gboolean cmde_ok = FALSE;
 				if (error) {
 					if (error->message)
 						str = g_strdup (error->message);
@@ -522,23 +561,29 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 					
 					cmde_ok = TRUE;
 				}
+				gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n", 1, 
+									  cmde_ok ? "result-ok" : "result-error", NULL);
+				gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, str, -1, 
+									  cmde_ok ? "result-ok" : "result-error", NULL);
+				gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n\n", 2, 
+									  cmde_ok ? "result-ok" : "result-error", NULL);
+				g_free (str);
 			}
 			hist_item->sql = rsql;
 		}
 		else {
+			gchar *str = NULL;
 			if (error && error->message)
 				str = g_strdup (error->message);
 			else
 				str = g_strdup (_("Error while computing SQL statement"));
+			gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n", 1, "result-error", NULL);
+			gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, _("Cancelled"), -1, "result-error", NULL);
+			gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n\n", 2, "result-error", NULL);
+			g_free (str);
 		}
 	}
 
-	/* actually print something */
-	gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n", 1, cmde_ok ? "result-ok" : "result-error", NULL);
-	gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, str, -1, cmde_ok ? "result-ok" : "result-error", NULL);	
-	gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, "\n\n", 2, cmde_ok ? "result-ok" : "result-error", NULL);
-
-	g_free (str);
 	if (dset)
 		g_object_unref (dset);
 	g_object_unref (query);
