@@ -1,6 +1,6 @@
 /* gnome-db-util.h
  *
- * Copyright (C) 2005 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2006 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -18,9 +18,14 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifndef __GNOME_DB_TOOLS__
+#define __GNOME_DB_TOOLS__
+
 #include <gtk/gtkcellrenderer.h>
 #include <libgda/gda-value.h>
 #include "gnome-db-decl.h"
 
-GnomeDbDataEntry *gnome_db_util_new_data_entry    (GdaValueType type, const gchar *entry_name);
-GtkCellRenderer  *gnome_db_util_new_cell_renderer (GdaValueType type, const gchar *entry_name);
+GnomeDbDataEntry *gnome_db_util_new_data_entry    (GdaDict *dict, GType type, const gchar *plugin_name);
+GtkCellRenderer  *gnome_db_util_new_cell_renderer (GdaDict *dict, GType type, const gchar *plugin_name);
+
+#endif
