@@ -55,8 +55,8 @@ struct _GnomeDbCanvasEntityClass
 
 /* generic widget's functions */
 GType          gnome_db_canvas_entity_get_type       (void);
-GnomeDbCanvasField *gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GnomeDbField *field);
-gdouble        gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GnomeDbField *field);
+GnomeDbCanvasField *gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GdaEntityField *field);
+gdouble        gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GdaEntityField *field);
 
 G_END_DECLS
 
