@@ -1,6 +1,6 @@
 /* gnome-db-canvas.c
  *
- * Copyright (C) 2002 - 2004 Vivien Malerba
+ * Copyright (C) 2002 - 2006 Vivien Malerba
  * Copyright (C) 2002 Fernando Martins
  *
  * This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
 #include "gnome-db-canvas.h"
 #include "gnome-db-canvas-tip.h"
 #include "gnome-db-canvas-cursor.h"
-#include "gnome-db-graph-item.h"
+#include <libgda/libgda.h>
 
 static void gnome_db_canvas_class_init (GnomeDbCanvasClass * class);
 static void gnome_db_canvas_init       (GnomeDbCanvas * canvas);
@@ -33,14 +33,14 @@ static void gnome_db_canvas_finalize   (GObject   * object);
 static void gnome_db_canvas_post_init  (GnomeDbCanvas * canvas);
 static void gnome_db_canvas_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
 
-static void gnome_db_canvas_set_property    (GObject              *object,
-				       guint                 param_id,
-				       const GValue         *value,
-				       GParamSpec           *pspec);
-static void gnome_db_canvas_get_property    (GObject              *object,
-				       guint                 param_id,
-				       GValue               *value,
-				       GParamSpec           *pspec);
+static void gnome_db_canvas_set_property    (GObject *object,
+				       guint param_id,
+				       const GValue *value,
+				       GParamSpec *pspec);
+static void gnome_db_canvas_get_property    (GObject *object,
+				       guint param_id,
+				       GValue *value,
+				       GParamSpec *pspec);
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
@@ -48,7 +48,7 @@ static GObjectClass *parent_class = NULL;
 
 struct _GnomeDbCanvasPrivate
 {
-	GnomeDbGraph            *graph;
+	GdaGraph           *graph;
 	GSList             *items; /* GnomeDbCanvasItem objects, non ordered */
 };
 
@@ -243,9 +243,9 @@ popup_zoom_fit_cb (GtkMenuItem *mitem, GnomeDbCanvas *canvas)
 }
 
 
-static void graph_nullified_cb (GnomeDbGraph *graph, GnomeDbCanvas *canvas);
-static void graph_item_added_cb (GnomeDbGraph *graph, GnomeDbGraphItem *item, GnomeDbCanvas *canvas);
-static void graph_item_dropped_cb (GnomeDbGraph *graph, GnomeDbGraphItem *item, GnomeDbCanvas *canvas);
+static void graph_destroyed_cb (GdaGraph *graph, GnomeDbCanvas *canvas);
+static void graph_item_added_cb (GdaGraph *graph, GdaGraphItem *item, GnomeDbCanvas *canvas);
+static void graph_item_dropped_cb (GdaGraph *graph, GdaGraphItem *item, GnomeDbCanvas *canvas);
 static void item_destroyed_cb (GnomeDbCanvasItem *item, GnomeDbCanvas *canvas);
 static void item_moved_cb (GnomeDbCanvasItem *item, GnomeDbCanvas *canvas);
 static void drag_action_cb (GnomeDbCanvasItem *citem, GnomeDbCanvasItem *drag_from, 
@@ -261,7 +261,7 @@ gnome_db_canvas_dispose (GObject   * object)
 	canvas = GNOME_DB_CANVAS (object);
 
 	if (canvas->priv->graph) 
-		graph_nullified_cb (canvas->priv->graph, canvas);
+		graph_destroyed_cb (canvas->priv->graph, canvas);
 
 	/* get rid of the GnomeCanvasItems */
 	while (canvas->priv->items) 
@@ -301,10 +301,10 @@ gnome_db_canvas_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 }
 
 static void 
-gnome_db_canvas_set_property    (GObject              *object,
-			   guint                 param_id,
-			   const GValue         *value,
-			   GParamSpec           *pspec)
+gnome_db_canvas_set_property    (GObject *object,
+			   guint param_id,
+			   const GValue *value,
+			   GParamSpec *pspec)
 {
 	GnomeDbCanvas *canvas;
 	gpointer ptr;
@@ -319,13 +319,13 @@ gnome_db_canvas_set_property    (GObject              *object,
 			return;
 
 		if (canvas->priv->graph) 
-			graph_nullified_cb (canvas->priv->graph, canvas);
+			graph_destroyed_cb (canvas->priv->graph, canvas);
 		
 		if (ptr) {
-			g_return_if_fail (IS_GNOME_DB_GRAPH (ptr));
-			canvas->priv->graph = GNOME_DB_GRAPH (ptr);
+			g_return_if_fail (GDA_IS_GRAPH (ptr));
+			canvas->priv->graph = GDA_GRAPH (ptr);
 			g_object_ref (G_OBJECT (ptr));
-			gnome_db_base_connect_nullify (ptr, G_CALLBACK (graph_nullified_cb), canvas);
+			gda_object_connect_destroy (ptr, G_CALLBACK (graph_destroyed_cb), canvas);
 			g_signal_connect (G_OBJECT (ptr), "item_added",
 					  G_CALLBACK (graph_item_added_cb), canvas);
 			g_signal_connect (G_OBJECT (ptr), "item_dropped",
@@ -340,10 +340,10 @@ gnome_db_canvas_set_property    (GObject              *object,
 }
 
 static void
-gnome_db_canvas_get_property    (GObject              *object,
-			   guint                 param_id,
-			   GValue               *value,
-			   GParamSpec           *pspec)
+gnome_db_canvas_get_property    (GObject *object,
+			   guint param_id,
+			   GValue *value,
+			   GParamSpec *pspec)
 {
 	GnomeDbCanvas *canvas;
 	
@@ -357,12 +357,12 @@ gnome_db_canvas_get_property    (GObject              *object,
 }
 
 static void
-graph_nullified_cb (GnomeDbGraph *graph, GnomeDbCanvas *canvas)
+graph_destroyed_cb (GdaGraph *graph, GnomeDbCanvas *canvas)
 {
 	g_return_if_fail (canvas->priv->graph == graph);
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (graph),
-					      G_CALLBACK (graph_nullified_cb), canvas);
+					      G_CALLBACK (graph_destroyed_cb), canvas);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (graph),
 					      G_CALLBACK (graph_item_added_cb), canvas);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (graph),
@@ -375,7 +375,7 @@ graph_nullified_cb (GnomeDbGraph *graph, GnomeDbCanvas *canvas)
 }
 
 static void
-graph_item_added_cb (GnomeDbGraph *graph, GnomeDbGraphItem *item, GnomeDbCanvas *canvas)
+graph_item_added_cb (GdaGraph *graph, GdaGraphItem *item, GnomeDbCanvas *canvas)
 {
 	GnomeDbCanvasClass *class = GNOME_DB_CANVAS_CLASS (G_OBJECT_GET_CLASS (canvas));
 	if (class->graph_item_added)
@@ -383,7 +383,7 @@ graph_item_added_cb (GnomeDbGraph *graph, GnomeDbGraphItem *item, GnomeDbCanvas
 }
 
 static void
-graph_item_dropped_cb (GnomeDbGraph *graph, GnomeDbGraphItem *item, GnomeDbCanvas *canvas)
+graph_item_dropped_cb (GdaGraph *graph, GdaGraphItem *item, GnomeDbCanvas *canvas)
 {
 	GnomeDbCanvasClass *class = GNOME_DB_CANVAS_CLASS (G_OBJECT_GET_CLASS (canvas));
 	if (class->graph_item_dropped)
@@ -409,7 +409,7 @@ gnome_db_canvas_post_init  (GnomeDbCanvas *canvas)
 	canvas_scrollbar_adjust (canvas);
 }
 
-GnomeDbGraph *
+GdaGraph *
 gnome_db_canvas_get_graph (GnomeDbCanvas *canvas)
 {
 	g_return_val_if_fail (canvas && IS_GNOME_DB_CANVAS (canvas), NULL);
@@ -520,12 +520,12 @@ move_all_items (GnomeDbCanvas *canvas, gdouble wdx, gdouble wdy)
 
 	list = canvas->priv->items;
 	while (list) {
-		GnomeDbGraphItem *item = gnome_db_canvas_item_get_graph_item (GNOME_DB_CANVAS_ITEM (list->data));
+		GdaGraphItem *item = gnome_db_canvas_item_get_graph_item (GNOME_DB_CANVAS_ITEM (list->data));
 		if (item) {
-			gnome_db_graph_item_get_position (item, &px, &py);
+			gda_graph_item_get_position (item, &px, &py);
 			px += wdx;
 			py += wdy;
-			gnome_db_graph_item_set_position (item, px, py);
+			gda_graph_item_set_position (item, px, py);
 			moved = TRUE;
 		}
 		list = g_slist_next (list);
@@ -607,14 +607,14 @@ canvas_scrollbar_adjust (GnomeDbCanvas *canvas)
  * Returns:
  */
 GnomeDbCanvasItem *
-gnome_db_canvas_get_item_for_object (GnomeDbCanvas *canvas, GnomeDbBase *ref_obj)
+gnome_db_canvas_get_item_for_object (GnomeDbCanvas *canvas, GdaObject *ref_obj)
 {
 	GnomeDbCanvasItem *item = NULL;
 	GSList *list = canvas->priv->items;
 
 	while (list && !item) {
-		GnomeDbGraphItem *gitem = gnome_db_canvas_item_get_graph_item (GNOME_DB_CANVAS_ITEM (list->data));
-		if (gitem && (gnome_db_graph_item_get_ref_object (gitem) == ref_obj))
+		GdaGraphItem *gitem = gnome_db_canvas_item_get_graph_item (GNOME_DB_CANVAS_ITEM (list->data));
+		if (gitem && (gda_graph_item_get_ref_object (gitem) == ref_obj))
 			item = GNOME_DB_CANVAS_ITEM (list->data);
 
 		list = g_slist_next (list);
